# Longitude and Latitude Values

- [1. ![badge](https://img.shields.io/badge/Required-blue) Property `Longitude and Latitude Values > latitude`](#latitude)
- [2. ![badge](https://img.shields.io/badge/Required-blue) Property `Longitude and Latitude Values > longitude`](#longitude)

**Title:** Longitude and Latitude Values

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** A geographical coordinate.

| Property                   | Pattern | Type   | Deprecated | Definition | Title/Description |
| -------------------------- | ------- | ------ | ---------- | ---------- | ----------------- |
| + [latitude](#latitude )   | No      | number | No         | -          | -                 |
| + [longitude](#longitude ) | No      | number | No         | -          | -                 |
|                            |         |        |            |            |                   |

## <a name="latitude"></a>1. ![badge](https://img.shields.io/badge/Required-blue) Property `Longitude and Latitude Values > latitude`

| Type                      | `number`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

| Restrictions |          |
| ------------ | -------- |
| **Minimum**  | &ge; -90 |
| **Maximum**  | &le; 90  |
|              |          |

## <a name="longitude"></a>2. ![badge](https://img.shields.io/badge/Required-blue) Property `Longitude and Latitude Values > longitude`

| Type                      | `number`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

| Restrictions |           |
| ------------ | --------- |
| **Minimum**  | &ge; -180 |
| **Maximum**  | &le; 180  |
|              |           |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date